﻿using System;
using System.Drawing;
using System.Runtime.InteropServices;
using System.Windows.Forms;
using ThinkGeo.Core;
using WpfDotNetFramwork;

namespace WindowsFormsApp18
{
    public partial class Form1 : Form
    {
        [DllImport("user32.dll", SetLastError = true)]
        internal static extern bool SetProcessDpiAwarenessContext(int dpiFlag);

        public Form1()
        {
            SetProcessDpiAwarenessContext(-5);

            InitializeComponent();
        }

        private void Form1_Load_1(object sender, EventArgs e)
        {

          //  this.AutoScaleMode = System.Windows.Forms.AutoScaleMode.Dpi;
            this.Font = new System.Drawing.Font("Arial", 14F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Pixel, ((byte)(0)));

            MapView1.MapUnit = GeographyUnit.Meter;

            OpenStreetMapOverlay osmOverlay1 = new OpenStreetMapOverlay();
            MapView1.Overlays.Add("Open Street Map", osmOverlay1);
            var thinkGeoCloudVectorMapsOverlay = new ThinkGeoCloudVectorMapsOverlay("itZGOI8oafZwmtxP-XGiMvfWJPPc-dX35DmESmLlQIU~", "bcaCzPpmOG6le2pUz5EAaEKYI-KSMny_WxEAe7gMNQgGeN9sqL12OA~~", ThinkGeoCloudVectorMapsMapType.Light);
            //MapView1.Overlays.Add(thinkGeoCloudVectorMapsOverlay);

            // mapWidh is 862 when scale is 100%.
            // mapWidh is 431 when scale is 200%.
            double mapWidth = MapView1.ActualWidth;   

            float scaleFactor = 1;
            //Graphics graphics = this.CreateGraphics();
            //float dpiX = graphics.DpiX;
            //scaleFactor = dpiX / 96f;

            GeoImage needleImage = new GeoImage(Application.StartupPath + "\\compass1_needle_letters_disc.png");
            //Gets the image for the frame of the compass that will stay fixed.

            GeoImage frameImage = new GeoImage(Application.StartupPath + "\\compass1_circle_digits.png");
            CompassAdornmentLayer compassAdornmentLayer = new CompassAdornmentLayer(needleImage, frameImage, Position.UpperLeft, 100, scaleFactor);

            MapView1.AdornmentOverlay.Layers.Add(compassAdornmentLayer);
        }


        public void InitTimer_Tick(object sender, EventArgs e)
        {
            GoogleMapsZoomLevelSet googleMapZoomLevelSet = new GoogleMapsZoomLevelSet();
            MapView1.ZoomLevelSet = googleMapZoomLevelSet;
            double SavedInRegistryMap1Scale = MapView1.ZoomLevelSet.ZoomLevel18.Scale; // For example
            if (SavedInRegistryMap1Scale > MapView1.ZoomLevelSet.ZoomLevel01.Scale || SavedInRegistryMap1Scale < MapView1.ZoomLevelSet.ZoomLevel20.Scale)
                SavedInRegistryMap1Scale = MapView1.ZoomLevelSet.ZoomLevel18.Scale;
            MapView1.CurrentExtent = MapUtil.ZoomToScale(SavedInRegistryMap1Scale, MapView1.CurrentExtent, GeographyUnit.DecimalDegree, MapView1.Width, MapView1.Height);
            double SavedExtentCenterPointX = 0, SavedExtentCenterPointY = 0;
            MapView1.CenterAt(new PointShape(SavedExtentCenterPointX, SavedExtentCenterPointY));

            //Doc.MainVehicle.CurrentPosition = new Position(Map1.CurrentExtent.GetCenterPoint());
            //Map1UpdateVehicleLayer();
            //UpdateDestination();
            Map1RefreshDynamicOverlay();
            Map1RefreshAdornmentOverlay();
            //Map2Update();
        }


        public void Map1RefreshDynamicOverlay()
        {
            if (InvokeRequired)
                Invoke(new MethodInvoker(delegate () { Map1RefreshDynamicOverlay(); }));
            else
            {
                try { /*MapView1.Refresh(DynamicOverlay); */}
                catch { }
            }
        }

        public void Map1RefreshAdornmentOverlay()
        {
            if (InvokeRequired)
                Invoke(new MethodInvoker(delegate () { Map1RefreshAdornmentOverlay(); }));
            else
            {
                try { MapView1.Refresh(MapView1.AdornmentOverlay); }
                catch { }
            }
        }
        private void panel1_Paint(object sender, PaintEventArgs e)
        {
            base.OnPaint(e);
            Bitmap CompassBmp = new Bitmap(Application.StartupPath + "\\compass1_needle_letters_disc.png");
            Bitmap DigitsBmp = new Bitmap(Application.StartupPath + "\\compass1_circle_digits.png");
            using (Graphics g = e.Graphics)
            {
                var p = new Pen(Color.Black, 3);
                g.DrawImage(CompassBmp, 0, 0);
                g.DrawImage(DigitsBmp, 0, 0);
            }
        }

        private void Form1_KeyDown(object sender, KeyEventArgs e)
        {
            switch (e.KeyCode)
            {
                case Keys.F3:
                    MapView1.ZoomToScale(MapView1.CurrentScale / 2);
                    MapView1.Refresh();
                    break;
                case Keys.F4:
                    MapView1.ZoomToScale(MapView1.CurrentScale * 2);
                    MapView1.Refresh();
                    break;
                default:
                    break;
            }
        }

        private void MapView1_MapKeyDown(object sender, System.Windows.Input.KeyEventArgs e)
        {
            switch (e.Key)
            {

                case System.Windows.Input.Key.F3:
                    MapView1.ZoomToScale(MapView1.CurrentScale / 2);
                    MapView1.Refresh();
                    break;
                case System.Windows.Input.Key.F4:
                    MapView1.ZoomToScale(MapView1.CurrentScale * 2);
                    MapView1.Refresh();
                    break;
                default:
                    break;
            }
        }
    }
}
